@@ -166,8 +166,11 @@ static int acpi_parse_one_dev_scope(fwts_framework *fw,
 			goto error;
 		dev_type = read_pci_device_secondary_bus_number(seg, bus,
 			path->dev, path->fn, &sec_bus);
-		if (dev_type < 0) /* no such device */
+		if (dev_type < 0) {	/* no such device */
+			fwts_warning(fw, "PCI device %04Xh:%02Xh:%02Xh.%02Xh is not found.",
+				     seg, bus, path->dev, path->fn);
 			goto error;
+		}
 		path++;
 		count--;
 		bus = sec_bus;
@@ -187,7 +190,7 @@ error:
 }
 
 static int acpi_parse_dev_scope(fwts_framework *fw,
-	uint8_t *start, uint8_t *end, const uint16_t seg)
+	uint8_t *start, const uint8_t *end, const uint16_t seg)
 {
 	while (start < end) {
 		struct acpi_dev_scope *scope = (struct acpi_dev_scope *)start;
@@ -335,6 +338,6 @@ static fwts_framework_ops dmar_ops = {
 	.minor_tests = dmar_tests
 };
 
-FWTS_REGISTER("dmar", &dmar_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI | FWTS_FLAG_ROOT_PRIV)
+FWTS_REGISTER("dmar", &dmar_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI | FWTS_FLAG_ROOT_PRIV)
 
 #endif
