@@ -49,7 +49,7 @@
  * and made a pact to keep their own counter.  Every time the MADT found a
  * new subtable, or a subtable grew up, the wizards promised they would
  * increment their counter.  Well, wizards being the forgetful sort, they
- * didn't alway do that.  And, since there quite a lot of them, they
+ * didn't always do that.  And, since there quite a lot of them, they
  * couldn't always remember who was supposed to keep track of the MADT,
  * especially if dinner was coming up soon.  Their counter was called the
  * spec version.
@@ -385,7 +385,7 @@ static int madt_init(fwts_framework *fw)
 
 	fadt_major = fadt->header.revision;
 	fadt_minor = 0;
-	if (fw->flags & FWTS_FLAG_TEST_SBBR) {
+	if (fw->flags & FWTS_FLAG_SBBR) {
 		if (fadt_major < SBBR_ACPI_MAJOR_VERSION) {
 			fwts_log_error(fw, "SBBR support starts with ACPI v6.0,"
 					" Current revision is outdated: %" PRIu8 ".%" PRIu8,
@@ -393,9 +393,7 @@ static int madt_init(fwts_framework *fw)
 			return FWTS_ERROR;
 		}
 	}
-
-	if (fadt_major >= 5 && fadt->header.length >= 268)
-		fadt_minor = fadt->minor_version;   /* field added ACPI 5.1 */
+	fwts_get_fadt_version(fw, &fadt_major, &fadt_minor);
 
 	/* find the first occurrence for this version of MADT */
 	while (ms->num_types != 0) {
@@ -567,7 +565,10 @@ static const char *madt_sub_names[] = {
 };
 
 /* check flags points to Table 5-48 Local APIC Flags */
-static void check_madt_apic_flags(fwts_framework *fw, uint8_t type, uint32_t flags)
+static void check_madt_apic_flags(
+	fwts_framework *fw,
+	const uint8_t type,
+	const uint32_t flags)
 {
 	fwts_acpi_table_madt *madt = (fwts_acpi_table_madt *) mtable->data;
 	bool passed = true;
@@ -576,7 +577,7 @@ static void check_madt_apic_flags(fwts_framework *fw, uint8_t type, uint32_t fla
 	if (madt->header.revision < 5)
 		head = 1;
 
-	fwts_acpi_reserved_bits_check("MADT", "Local APIC Flags", flags, head, 31, &passed);
+	fwts_acpi_reserved_bits("MADT", "Local APIC Flags", flags, head, 31, &passed);
 
 	if (passed)
 		fwts_passed(fw, "MADT %s flags field, bits %" PRIu8
@@ -883,7 +884,8 @@ static int madt_local_sapic(fwts_framework *fw,
 	}
 
 	for (tmp = 0, ii = 0; ii < 3; tmp |= lsapic->reserved[ii], ii++)
-		continue;
+		;
+
 	if (tmp)
 		fwts_failed(fw, LOG_LEVEL_MEDIUM,
 			    "MADTLSAPICReservedNonZero",
@@ -1416,7 +1418,7 @@ static int madt_mp_wakup(fwts_framework *fw,
 	if (mp_wakeup->mail_box_address % 0x1000)
 		fwts_failed(fw, LOG_LEVEL_HIGH,
 			    "SPECMADTMPWAKEUPAddress",
-			    "MADT %s mailbox adress should be 4K bytes aligned, "
+			    "MADT %s mailbox address should be 4K bytes aligned, "
 			    "but instead have 0x%" PRIx64 ".",
 			    madt_sub_names[hdr->type], mp_wakeup->mail_box_address);
 	else
@@ -1525,9 +1527,9 @@ static int madt_subtables(fwts_framework *fw)
 		/* check for OEM and reserved entries */
 		if (hdr->type >= NUM_SUBTABLE_TYPES) {
 			if (hdr->type < 0x80)
-				type = FWTS_ACPI_MADT_RESERVED;
+				type = FWTS_MADT_RESERVED;
 			else
-				type = FWTS_ACPI_MADT_OEM;
+				type = FWTS_MADT_OEM;
 			len = hdr->length;
 		} else {
 			/* this subtable is defined */
@@ -1546,12 +1548,12 @@ static int madt_subtables(fwts_framework *fw)
 				    hdr->type, madt_sub_names[type]);
 		}
 
-		if (!(fw->flags & FWTS_FLAG_TEST_SBBR)) {
+		if (!(fw->flags & FWTS_FLAG_SBBR)) {
 			bool passed = true;
 
 			/* verify that the length is what we expect */
 			if (len == SUBTABLE_VARIABLE) {
-				if (hdr->type == FWTS_ACPI_MADT_LOCAL_SAPIC) {
+				if (hdr->type == FWTS_MADT_LOCAL_SAPIC) {
 					lsapic = (fwts_acpi_madt_local_sapic *)hdr;
 					proper_len =
 					     sizeof(fwts_acpi_madt_local_sapic) +
@@ -1585,77 +1587,77 @@ static int madt_subtables(fwts_framework *fw)
 
 		/* perform checks specific to subtable types */
 		switch (type) {
-		case FWTS_ACPI_MADT_LOCAL_APIC:
+		case FWTS_MADT_LOCAL_APIC:
 			skip = madt_local_apic(fw, hdr, data);
 			break;
 
-		case FWTS_ACPI_MADT_IO_APIC:
+		case FWTS_MADT_IO_APIC:
 			skip = madt_io_apic(fw, hdr, data);
 			num_ioapics++;
 			break;
 
-		case FWTS_ACPI_MADT_INTERRUPT_OVERRIDE:
+		case FWTS_MADT_INTERRUPT_OVERRIDE:
 			skip = madt_interrupt_override(fw, hdr, data);
 			break;
 
-		case FWTS_ACPI_MADT_NMI_SOURCE:
+		case FWTS_MADT_NMI_SOURCE:
 			skip = madt_nmi_source(fw, hdr, data);
 			break;
 
-		case FWTS_ACPI_MADT_LOCAL_APIC_NMI:
+		case FWTS_MADT_LOCAL_APIC_NMI:
 			skip = madt_local_apic_nmi(fw, hdr, data);
 			break;
 
-		case FWTS_ACPI_MADT_LOCAL_APIC_OVERRIDE:
+		case FWTS_MADT_LOCAL_APIC_OVERRIDE:
 			skip = madt_lapic_addr_override(fw, hdr, data);
 			break;
 
-		case FWTS_ACPI_MADT_IO_SAPIC:
+		case FWTS_MADT_IO_SAPIC:
 			skip = madt_io_sapic(fw, hdr, data);
 			num_iosapics++;
 			break;
 
-		case FWTS_ACPI_MADT_LOCAL_SAPIC:
+		case FWTS_MADT_LOCAL_SAPIC:
 			skip = madt_local_sapic(fw, hdr, data);
 			break;
 
-		case FWTS_ACPI_MADT_INTERRUPT_SOURCE:
+		case FWTS_MADT_INTERRUPT_SOURCE:
 			skip = madt_platform_int_source(fw, hdr, data);
 			break;
 
-		case FWTS_ACPI_MADT_LOCAL_X2APIC:
+		case FWTS_MADT_LOCAL_X2APIC:
 			skip = madt_local_x2apic(fw, hdr, data);
 			break;
 
-		case FWTS_ACPI_MADT_LOCAL_X2APIC_NMI:
+		case FWTS_MADT_LOCAL_X2APIC_NMI:
 			skip = madt_local_x2apic_nmi(fw, hdr, data);
 			break;
 
-		case FWTS_ACPI_MADT_GIC_C_CPU_INTERFACE:
+		case FWTS_MADT_GIC_C_CPU_INTERFACE:
 			skip = madt_gicc(fw, hdr, data);
 			break;
 
-		case FWTS_ACPI_MADT_GIC_D_GOC_DISTRIBUTOR:
+		case FWTS_MADT_GIC_D_GOC_DISTRIBUTOR:
 			skip = madt_gicd(fw, hdr, data);
 			break;
 
-		case FWTS_ACPI_MADT_GIC_V2M_MSI_FRAME:
+		case FWTS_MADT_GIC_V2M_MSI_FRAME:
 			skip = madt_gic_msi_frame(fw, hdr, data);
 			break;
 
-		case FWTS_ACPI_MADT_GIC_R_REDISTRIBUTOR:
+		case FWTS_MADT_GIC_R_REDISTRIBUTOR:
 			skip = madt_gicr(fw, hdr, data);
 			break;
 
-		case FWTS_ACPI_MADT_GIC_ITS:
+		case FWTS_MADT_GIC_ITS:
 			skip = madt_gic_its(fw, hdr, data);
 			break;
 
-		case FWTS_ACPI_MADT_MP_WAKEUP:
+		case FWTS_MADT_MP_WAKEUP:
 			skip = madt_mp_wakup(fw, hdr, data);
 			break;
 
-		case FWTS_ACPI_MADT_RESERVED:
+		case FWTS_MADT_RESERVED:
 			fwts_failed(fw, LOG_LEVEL_MEDIUM,
 				    "SPECMADTSubReservedID",
 				    "MADT subtable %d (offset 0x%x) is "
@@ -1663,11 +1665,11 @@ static int madt_subtables(fwts_framework *fw)
 				    "type.  Subtable type values 0x%" PRIx8 "..0x7f "
 				    "are reserved; 0x80..0xff can be "
 				    "used by OEMs.",
-				    ii, offset, hdr->type, FWTS_ACPI_MADT_RESERVED);
+				    ii, offset, hdr->type, FWTS_MADT_RESERVED);
 			skip = (hdr->length -
 				sizeof(fwts_acpi_madt_sub_table_header));
 			break;
-		case FWTS_ACPI_MADT_OEM:
+		case FWTS_MADT_OEM:
 			/* OEM entries must be assumed to be valid */
 			skip = (hdr->length -
 				sizeof(fwts_acpi_madt_sub_table_header));
@@ -1697,7 +1699,7 @@ static int madt_subtables(fwts_framework *fw)
 		length -= skip;
 	}
 
-	if (!(fw->flags & FWTS_FLAG_TEST_SBBR)) {
+	if (!(fw->flags & FWTS_FLAG_SBBR)) {
 		/* run comparison tests */
 		madt_ioapic_sapic_compare(fw, num_ioapics, num_iosapics);
 	}
@@ -1733,6 +1735,6 @@ static fwts_framework_ops madt_ops = {
 	.minor_tests = madt_tests
 };
 
-FWTS_REGISTER("madt", &madt_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI | FWTS_FLAG_TEST_COMPLIANCE_ACPI | FWTS_FLAG_TEST_SBBR)
+FWTS_REGISTER("madt", &madt_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI | FWTS_FLAG_COMPLIANCE_ACPI | FWTS_FLAG_SBBR)
 
 #endif
