@@ -26,18 +26,9 @@
 static fwts_firmware_type firmware_type;
 static bool firmware_type_valid;
 
-static const struct {
-	fwts_firmware_feature feature;
-	const char name[16];
-} feature_names[] = {
-	{ FWTS_FW_FEATURE_ACPI,		"ACPI" },
-	{ FWTS_FW_FEATURE_DEVICETREE,	"devicetree" },
-	{ FWTS_FW_FEATURE_IPMI,		"IPMI" },
-};
-
 /*
- *  fwts_memory_map_entry_compare()
- *	callback used to sort memory_map entries on start address
+ *  fwts_firmware_detect()
+ *   check system firmware type
  */
 fwts_firmware_type fwts_firmware_detect(void)
 {
@@ -63,22 +54,15 @@ fwts_firmware_type fwts_firmware_detect(void)
 int fwts_firmware_features(void)
 {
 	int features = 0;
-	struct stat ipmi_statbuf;
+	struct stat statbuf;
 
-	switch (fwts_firmware_detect()) {
-	case FWTS_FIRMWARE_BIOS:
-	case FWTS_FIRMWARE_UEFI:
-		features = FWTS_FW_FEATURE_ACPI;
-		break;
-	case FWTS_FIRMWARE_OPAL:
-		features = FWTS_FW_FEATURE_DEVICETREE;
-		break;
-	default:
-		break;
-	}
+	if (!stat("/sys/firmware/acpi", &statbuf))
+		features |= FWTS_FW_FEATURE_ACPI;
+	else if (!stat("/sys/firmware/devicetree/base", &statbuf))
+		features |= FWTS_FW_FEATURE_DEVICETREE;
 
 	/* just check for IPMI device presence */
-	if (!stat("/dev/ipmi0", &ipmi_statbuf))
+	if (!stat("/dev/ipmi0", &statbuf))
 		features |= FWTS_FW_FEATURE_IPMI;
 
 	return features;
@@ -86,6 +70,15 @@ int fwts_firmware_features(void)
 
 const char *fwts_firmware_feature_string(const fwts_firmware_feature features)
 {
+	static const struct {
+		const fwts_firmware_feature feature;
+		const char name[16];
+	} feature_names[] = {
+		{ FWTS_FW_FEATURE_ACPI,		"ACPI" },
+		{ FWTS_FW_FEATURE_DEVICETREE,	"devicetree" },
+		{ FWTS_FW_FEATURE_IPMI,		"IPMI" },
+	};
+
 	const int n = FWTS_ARRAY_SIZE(feature_names);
 	static const char sep[] = ", ";
 	static char str[60];
