@@ -35,8 +35,6 @@
 
 #include "fwts.h"
 
-#if defined(FWTS_HAS_ACPI)
-
 /* ACPICA specific headers */
 #include "acpi.h"
 #include "accommon.h"
@@ -219,7 +217,7 @@ static ACPI_STATUS fwts_exception_handler(
 	if (AcpiGbl_IgnoreErrors) {
 		if (AmlStatus != AE_OK) {
 			fwts_log_info(fwts_acpica_fw,
-				"ACPICA Exception override, forcing AE_OK for execption %s",
+				"ACPICA Exception override, forcing AE_OK for exception %s",
 				exception);
 			AmlStatus = AE_OK;
 		}
@@ -1321,7 +1319,7 @@ static ACPI_STATUS fwts_acpi_walk_for_object_names(
  *  fwts_acpica_get_object_names()
  *	fetch a list of object names that match a specified type
  */
-fwts_list *fwts_acpica_get_object_names(int type)
+fwts_list *fwts_acpica_get_object_names(const int type)
 {
 	fwts_list *list;
 
@@ -1331,50 +1329,3 @@ fwts_list *fwts_acpica_get_object_names(int type)
 
 	return list;
 }
-
-#else
-
-static void __void_func(const char *funcname)
-{
-	fprintf(stderr, "fwts ACPICA library: unexpected call to %s()\n", funcname);
-	exit(EXIT_FAILURE);
-}
-
-#define VOID_FUNC(name) void name(void) { __void_func(#name); }
-
-/*
- *  With ACPI disabled, these functions should never
- *  be called. We should defined this otherwise we will
- *  get linker errors with some autotools/linker combos
- */
-VOID_FUNC(AcpiGbl_IgnoreErrors)
-VOID_FUNC(AcpiGbl_RegionFillValue)
-
-VOID_FUNC(AcpiOsCreateSemaphore)
-VOID_FUNC(AcpiOsDeleteSemaphore)
-VOID_FUNC(AcpiOsExecute)
-VOID_FUNC(AcpiOsGetRootPointer)
-VOID_FUNC(AcpiOsPrintf)
-VOID_FUNC(AcpiOsReadPciConfiguration)
-VOID_FUNC(AcpiOsReadPort)
-VOID_FUNC(AcpiOsSignal)
-VOID_FUNC(AcpiOsSignalSemaphore)
-VOID_FUNC(AcpiOsSleep)
-VOID_FUNC(AcpiOsVprintf)
-VOID_FUNC(AcpiOsWaitSemaphore)
-
-VOID_FUNC(AeTableOverride)
-
-VOID_FUNC(MpSaveGpioInfo)
-VOID_FUNC(MpSaveSerialInfo)
-
-/*
- * We need this otherwise gcc 4.5 ends up with a linker failure
- * when building with ACPI disabled and I have no idea why.
- */
-unsigned char AcpiGbl_AbortLoopOnTimeout = FALSE;
-unsigned char AcpiGbl_VerboseHandlers = FALSE;
-void *AcpiGbl_InitEntries = NULL;
-uint32_t AcpiGbl_InitFileLineCount = 0;
-
-#endif
